---
title: Exceptions module
summary: Exceptions raised by the library
---

These are all the exceptions raised by the library.

::: pyown.exceptions.OWNException

::: pyown.exceptions.ParseError
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.InvalidData
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.InvalidMessage
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.InvalidTag
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.InvalidSession
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.InvalidAuthentication
    options:
        show_inheritance_diagram: true

::: pyown.exceptions.ResponseError
    options:
        show_inheritance_diagram: true
